import { GraphQLResolveInfo } from 'graphql';
import { GraphQLSchema } from 'graphql';
import { DocumentNode } from 'graphql';
import { CompilerOptions } from 'graphql-jit';
export declare type Maybe<T> = T | null;
export declare type InputMaybe<T> = Maybe<T>;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    /** The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text. */
    String: string;
    Boolean: boolean;
    /** The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1. */
    Int: number;
    /** The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point). */
    Float: number;
};
export declare type Query = {
    /** POST /pull_expenses */
    getExpenses?: Maybe<getExpensesResponse>;
};
export declare type QuerygetExpensesArgs = {
    input?: InputMaybe<getExpensesRequest_Input>;
};
export declare type getExpensesResponse = {
    description: Scalars['String'];
    /** An array of JSON of the search */
    expenses?: Maybe<Array<Maybe<Expense>>>;
    /** The next available page */
    next_page?: Maybe<Scalars['String']>;
    result: Scalars['Int'];
    /** The total size of the query */
    total_entries?: Maybe<Scalars['Int']>;
    /** The total pages of the query */
    total_pages?: Maybe<Scalars['String']>;
};
/** A Single Expense */
export declare type Expense = {
    created_at: Scalars['String'];
    currency_symbol?: Maybe<Expense_currency_symbol>;
    document_date?: Maybe<Scalars['String']>;
    document_id?: Maybe<Scalars['String']>;
    document_type?: Maybe<Scalars['String']>;
    file_name: Scalars['String'];
    file_url: Scalars['String'];
    foreign_total_for_payment?: Maybe<Scalars['Float']>;
    original_file_name?: Maybe<Scalars['String']>;
    provider: Scalars['String'];
    provider_business_num: Scalars['String'];
    recognized_vat_payment: Scalars['Float'];
    remarks?: Maybe<Scalars['String']>;
    status_classification: Scalars['String'];
    system_id: Scalars['Int'];
    total_for_payment: Scalars['Float'];
    total_for_vat: Scalars['Float'];
    updated_at: Scalars['String'];
    vat_payment: Scalars['Float'];
};
export declare type Expense_currency_symbol = 'EUR' | 'USD' | 'ILS';
export declare type getExpensesRequest_Input = {
    api_user?: InputMaybe<Scalars['String']>;
    query_options?: InputMaybe<getExpensesRequest_query_options_Input>;
};
export declare type getExpensesRequest_query_options_Input = {
    updated_from?: InputMaybe<Scalars['String']>;
    updated_to?: InputMaybe<Scalars['String']>;
    created_from?: InputMaybe<Scalars['String']>;
    created_to?: InputMaybe<Scalars['String']>;
    document_date_from?: InputMaybe<Scalars['String']>;
    document_date_to?: InputMaybe<Scalars['String']>;
    document_id?: InputMaybe<Scalars['String']>;
    /** default: -100000000 */
    system_id?: InputMaybe<Scalars['Int']>;
    order?: InputMaybe<getExpensesRequest_query_options_order>;
    /** default: 1 */
    page?: InputMaybe<Scalars['Int']>;
    /** default: 50 */
    per_page?: InputMaybe<Scalars['Int']>;
};
export declare type getExpensesRequest_query_options_order = 'document_date';
export declare type WithIndex<TObject> = TObject & Record<string, any>;
export declare type ResolversObject<TObject> = WithIndex<TObject>;
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterable<TResult> | Promise<AsyncIterable<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type ResolversTypes = ResolversObject<{
    Query: ResolverTypeWrapper<{}>;
    getExpensesResponse: ResolverTypeWrapper<getExpensesResponse>;
    String: ResolverTypeWrapper<Scalars['String']>;
    Expense: ResolverTypeWrapper<Expense>;
    Expense_currency_symbol: Expense_currency_symbol;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    getExpensesRequest_Input: getExpensesRequest_Input;
    getExpensesRequest_query_options_Input: getExpensesRequest_query_options_Input;
    getExpensesRequest_query_options_order: getExpensesRequest_query_options_order;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
}>;
/** Mapping between all available schema types and the resolvers parents */
export declare type ResolversParentTypes = ResolversObject<{
    Query: {};
    getExpensesResponse: getExpensesResponse;
    String: Scalars['String'];
    Expense: Expense;
    Float: Scalars['Float'];
    Int: Scalars['Int'];
    getExpensesRequest_Input: getExpensesRequest_Input;
    getExpensesRequest_query_options_Input: getExpensesRequest_query_options_Input;
    Boolean: Scalars['Boolean'];
}>;
export declare type QueryResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = ResolversObject<{
    getExpenses?: Resolver<Maybe<ResolversTypes['getExpensesResponse']>, ParentType, ContextType, RequireFields<QuerygetExpensesArgs, never>>;
}>;
export declare type getExpensesResponseResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['getExpensesResponse'] = ResolversParentTypes['getExpensesResponse']> = ResolversObject<{
    description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    expenses?: Resolver<Maybe<Array<Maybe<ResolversTypes['Expense']>>>, ParentType, ContextType>;
    next_page?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    result?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    total_entries?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    total_pages?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;
export declare type ExpenseResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['Expense'] = ResolversParentTypes['Expense']> = ResolversObject<{
    created_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    currency_symbol?: Resolver<Maybe<ResolversTypes['Expense_currency_symbol']>, ParentType, ContextType>;
    document_date?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    document_id?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    document_type?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    file_name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    file_url?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    foreign_total_for_payment?: Resolver<Maybe<ResolversTypes['Float']>, ParentType, ContextType>;
    original_file_name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    provider?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    provider_business_num?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    recognized_vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    remarks?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    status_classification?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    system_id?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    total_for_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    total_for_vat?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    updated_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;
export declare type Resolvers<ContextType = MeshContext> = ResolversObject<{
    Query?: QueryResolvers<ContextType>;
    getExpensesResponse?: getExpensesResponseResolvers<ContextType>;
    Expense?: ExpenseResolvers<ContextType>;
}>;
import { MeshContext as BaseMeshContext, MeshInstance } from '@graphql-mesh/runtime';
import { InContextSdkMethod } from '@graphql-mesh/types';
export declare type QueryPayperSdk = {
    getExpenses: InContextSdkMethod<Query['getExpenses'], QuerygetExpensesArgs, MeshContext>;
};
export declare type MutationPayperSdk = {};
export declare type SubscriptionPayperSdk = {};
export declare type PayperContext = {
    ["Payper"]: {
        Query: QueryPayperSdk;
        Mutation: MutationPayperSdk;
        Subscription: SubscriptionPayperSdk;
    };
};
export declare type MeshContext = PayperContext & BaseMeshContext;
import { GetMeshOptions } from '@graphql-mesh/runtime';
import { YamlConfig } from '@graphql-mesh/types';
import 'ts-node/register/transpile-only';
export declare const rawConfig: YamlConfig.Config;
export declare function getMeshOptions(): GetMeshOptions;
export declare const documentsInSDL: any[];
export declare function getBuiltMesh(): Promise<MeshInstance>;
export declare function getMeshSDK<TGlobalContext = any, TGlobalRoot = any, TOperationContext = any, TOperationRoot = any>(sdkOptions?: SdkOptions<TGlobalContext, TGlobalRoot>): Promise<{
    getExpenses_query(variables?: Exact<{
        input?: getExpensesRequest_Input;
    }>, context?: TOperationContext, root?: TOperationRoot): Promise<getExpenses_queryQuery>;
}>;
export declare type getExpenses_queryQueryVariables = Exact<{
    input?: InputMaybe<getExpensesRequest_Input>;
}>;
export declare type getExpenses_queryQuery = {
    getExpenses?: Maybe<(Pick<getExpensesResponse, 'description' | 'next_page' | 'result' | 'total_entries' | 'total_pages'> & {
        expenses?: Maybe<Array<Maybe<Pick<Expense, 'created_at' | 'currency_symbol' | 'document_date' | 'document_id' | 'document_type' | 'file_name' | 'file_url' | 'foreign_total_for_payment' | 'original_file_name' | 'provider' | 'provider_business_num' | 'recognized_vat_payment' | 'remarks' | 'status_classification' | 'system_id' | 'total_for_payment' | 'total_for_vat' | 'updated_at' | 'vat_payment'>>>>;
    })>;
};
export declare const getExpenses_queryDocument: DocumentNode;
export interface SdkOptions<TGlobalContext = any, TGlobalRoot = any> {
    globalContext?: TGlobalContext;
    globalRoot?: TGlobalRoot;
    jitOptions?: Partial<CompilerOptions>;
}
export declare function getSdk<TGlobalContext = any, TGlobalRoot = any, TOperationContext = any, TOperationRoot = any>(schema: GraphQLSchema, { globalContext, globalRoot, jitOptions }?: SdkOptions<TGlobalContext, TGlobalRoot>): {
    getExpenses_query(variables?: getExpenses_queryQueryVariables, context?: TOperationContext, root?: TOperationRoot): Promise<getExpenses_queryQuery>;
};
export declare type Sdk = ReturnType<typeof getSdk>;
