"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSdk = exports.getExpenses_queryDocument = exports.getMeshSDK = exports.getBuiltMesh = exports.documentsInSDL = exports.getMeshOptions = exports.rawConfig = void 0;
const tslib_1 = require("tslib");
const graphql_jit_1 = require("graphql-jit");
const utils_1 = require("@graphql-tools/utils");
const runtime_1 = require("@graphql-mesh/runtime");
const store_1 = require("@graphql-mesh/store");
const path_1 = require("path");
const transpile_only_1 = (0, tslib_1.__importDefault)(require("ts-node/register/transpile-only"));
const cache_inmemory_lru_1 = (0, tslib_1.__importDefault)(require("@graphql-mesh/cache-inmemory-lru"));
const json_schema_1 = (0, tslib_1.__importDefault)(require("@graphql-mesh/json-schema"));
const merger_bare_1 = (0, tslib_1.__importDefault)(require("@graphql-mesh/merger-bare"));
const transform_resolvers_composition_1 = (0, tslib_1.__importDefault)(require("@graphql-mesh/transform-resolvers-composition"));
const jsonSchema_json_cjs_1 = (0, tslib_1.__importDefault)(require("./sources/Payper/jsonSchema.json.cjs"));
const getExpensesResolver_1 = (0, tslib_1.__importDefault)(require("./../src/resolvers/getExpensesResolver"));
const importedModules = {
    // @ts-ignore
    ["ts-node/register/transpile-only"]: transpile_only_1.default,
    // @ts-ignore
    ["@graphql-mesh/cache-inmemory-lru"]: cache_inmemory_lru_1.default,
    // @ts-ignore
    ["@graphql-mesh/json-schema"]: json_schema_1.default,
    // @ts-ignore
    ["@graphql-mesh/merger-bare"]: merger_bare_1.default,
    // @ts-ignore
    ["@graphql-mesh/transform-resolvers-composition"]: transform_resolvers_composition_1.default,
    // @ts-ignore
    [".mesh/sources/Payper/jsonSchema.json.cjs"]: jsonSchema_json_cjs_1.default,
    // @ts-ignore
    ["src/resolvers/getExpensesResolver"]: getExpensesResolver_1.default
};
const baseDir = (0, path_1.join)(__dirname, '..');
const importFn = (moduleId) => {
    const relativeModuleId = ((0, path_1.isAbsolute)(moduleId) ? (0, path_1.relative)(baseDir, moduleId) : moduleId).split('\\').join('/');
    if (!(relativeModuleId in importedModules)) {
        throw new Error(`Cannot find module '${relativeModuleId}'.`);
    }
    return Promise.resolve(importedModules[relativeModuleId]);
};
const rootStore = new store_1.MeshStore('.mesh', new store_1.FsStoreStorageAdapter({
    cwd: baseDir,
    importFn,
}), {
    readonly: true,
    validate: false
});
require("ts-node/register/transpile-only");
const cache_inmemory_lru_2 = (0, tslib_1.__importDefault)(require("@graphql-mesh/cache-inmemory-lru"));
const utils_2 = require("@graphql-mesh/utils");
const utils_3 = require("@graphql-mesh/utils");
const json_schema_2 = (0, tslib_1.__importDefault)(require("@graphql-mesh/json-schema"));
const merger_bare_2 = (0, tslib_1.__importDefault)(require("@graphql-mesh/merger-bare"));
const transform_resolvers_composition_2 = (0, tslib_1.__importDefault)(require("@graphql-mesh/transform-resolvers-composition"));
const utils_4 = require("@graphql-mesh/utils");
exports.rawConfig = { "sources": [{ "name": "Payper", "handler": { "jsonSchema": { "baseUrl": "https://payper.co.il/app/api", "operationHeaders": { "API_KEY": "{env.PAYPER_MESH_AUTH_TOKEN}", "Content-Type": "application/json", "Accept": "application/json" }, "operations": [{ "type": "Query", "field": "getExpenses", "path": "/pull_expenses", "method": "POST", "requestSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesRequest", "responseSchema": "./json-schemas/payperSchema.json#/definitions/getExpensesResponse" }] } }, "transforms": [{ "resolversComposition": { "mode": "bare", "compositions": [{ "resolver": "Query.getExpenses", "composer": "src/resolvers/getExpensesResolver" }] } }] }], "serve": { "browser": false }, "sdk": { "generateOperations": { "selectionSetDepth": 2 } }, "require": ["ts-node/register/transpile-only"] };
async function getMeshOptions() {
    const cache = new cache_inmemory_lru_2.default({
        ...(exports.rawConfig.cache || {}),
        store: rootStore.child('cache'),
    });
    const pubsub = new utils_2.PubSub();
    const sourcesStore = rootStore.child('sources');
    const logger = new utils_3.DefaultLogger('🕸️');
    const sources = [];
    const transforms = [];
    const payperTransforms = [];
    const additionalTypeDefs = [];
    const payperHandler = new json_schema_2.default({
        name: exports.rawConfig.sources[0].name,
        config: exports.rawConfig.sources[0].handler["jsonSchema"],
        baseDir,
        cache,
        pubsub,
        store: sourcesStore.child(exports.rawConfig.sources[0].name),
        logger: logger.child(exports.rawConfig.sources[0].name),
        importFn
    });
    const merger = new merger_bare_2.default({
        cache,
        pubsub,
        logger: logger.child('BareMerger'),
        store: rootStore.child('bareMerger')
    });
    payperTransforms.push(new transform_resolvers_composition_2.default({
        apiName: exports.rawConfig.sources[0].name,
        config: exports.rawConfig.sources[0].transforms[0]["resolversComposition"],
        baseDir,
        cache,
        pubsub,
        importFn
    }));
    sources.push({
        name: 'Payper',
        handler: payperHandler,
        transforms: payperTransforms
    });
    const additionalResolversRawConfig = [];
    const additionalResolvers = await (0, utils_4.resolveAdditionalResolvers)(baseDir, additionalResolversRawConfig, importFn, pubsub);
    const liveQueryInvalidations = exports.rawConfig.liveQueryInvalidations;
    return {
        sources,
        transforms,
        additionalTypeDefs,
        additionalResolvers,
        cache,
        pubsub,
        merger,
        logger,
        liveQueryInvalidations,
    };
}
exports.getMeshOptions = getMeshOptions;
exports.documentsInSDL = [];
async function getBuiltMesh() {
    const meshConfig = await getMeshOptions();
    return (0, runtime_1.getMesh)(meshConfig);
}
exports.getBuiltMesh = getBuiltMesh;
async function getMeshSDK(sdkOptions) {
    const { schema } = await getBuiltMesh();
    return getSdk(schema, {
        jitOptions: {
            disableLeafSerialization: true,
            disablingCapturingStackErrors: true
        },
        ...sdkOptions,
    });
}
exports.getMeshSDK = getMeshSDK;
exports.getExpenses_queryDocument = { "kind": "Document", "definitions": [{ "kind": "OperationDefinition", "operation": "query", "name": { "kind": "Name", "value": "getExpenses_query" }, "variableDefinitions": [{ "kind": "VariableDefinition", "variable": { "kind": "Variable", "name": { "kind": "Name", "value": "input" } }, "type": { "kind": "NamedType", "name": { "kind": "Name", "value": "getExpensesRequest_Input" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "getExpenses" }, "arguments": [{ "kind": "Argument", "name": { "kind": "Name", "value": "input" }, "value": { "kind": "Variable", "name": { "kind": "Name", "value": "input" } } }], "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "description" } }, { "kind": "Field", "name": { "kind": "Name", "value": "expenses" }, "selectionSet": { "kind": "SelectionSet", "selections": [{ "kind": "Field", "name": { "kind": "Name", "value": "created_at" } }, { "kind": "Field", "name": { "kind": "Name", "value": "currency_symbol" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_date" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_id" } }, { "kind": "Field", "name": { "kind": "Name", "value": "document_type" } }, { "kind": "Field", "name": { "kind": "Name", "value": "file_name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "file_url" } }, { "kind": "Field", "name": { "kind": "Name", "value": "foreign_total_for_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "original_file_name" } }, { "kind": "Field", "name": { "kind": "Name", "value": "provider" } }, { "kind": "Field", "name": { "kind": "Name", "value": "provider_business_num" } }, { "kind": "Field", "name": { "kind": "Name", "value": "recognized_vat_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "remarks" } }, { "kind": "Field", "name": { "kind": "Name", "value": "status_classification" } }, { "kind": "Field", "name": { "kind": "Name", "value": "system_id" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_for_payment" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_for_vat" } }, { "kind": "Field", "name": { "kind": "Name", "value": "updated_at" } }, { "kind": "Field", "name": { "kind": "Name", "value": "vat_payment" } }] } }, { "kind": "Field", "name": { "kind": "Name", "value": "next_page" } }, { "kind": "Field", "name": { "kind": "Name", "value": "result" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_entries" } }, { "kind": "Field", "name": { "kind": "Name", "value": "total_pages" } }] } }] } }] };
function handleExecutionResult(result, operationName) {
    if (result.errors) {
        const originalErrors = result.errors.map(error => error.originalError || error);
        throw new utils_1.AggregateError(originalErrors, `Failed to execute ${operationName}: \n\t${originalErrors.join('\n\t')}`);
    }
    return result.data;
}
function getSdk(schema, { globalContext, globalRoot, jitOptions = {} } = {}) {
    const getExpenses_queryCompiled = (0, graphql_jit_1.compileQuery)(schema, exports.getExpenses_queryDocument, 'getExpenses_query', jitOptions);
    if (!((0, graphql_jit_1.isCompiledQuery)(getExpenses_queryCompiled))) {
        const originalErrors = getExpenses_queryCompiled?.errors?.map(error => error.originalError || error) || [];
        throw new utils_1.AggregateError(originalErrors, `Failed to compile getExpenses_query: \n\t${originalErrors.join('\n\t')}`);
    }
    return {
        async getExpenses_query(variables, context, root) {
            const result = await getExpenses_queryCompiled.query({
                ...globalRoot,
                ...root
            }, {
                ...globalContext,
                ...context
            }, variables);
            return handleExecutionResult(result, 'getExpenses_query');
        }
    };
}
exports.getSdk = getSdk;
